@@ -1,6 +1,11 @@
 import csv
+import json
 import logging
 
+import psycopg2
+
+from . import awsUtils
+
 # declare the logging object
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -11,9 +16,7 @@ def get_content_type(extension):
     logger.debug(f"get_content_type('{extension}') called")
 
     if extension == "xlsx":
-        content_type = (
-            "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
-        )
+        content_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
     elif extension == "png":
         content_type = "image/png"
     elif extension == "jpg":
@@ -73,3 +76,36 @@ def get_file_extension(file):
     extension = file.split(".")[-1]
 
     return extension
+
+def execute_pgsql_query(sql, host=None, port=None, user=None, password=None, dbname=None, secrets_manager_key=None):
+    """executes a psql query"""
+    logger.debug(f"execute_pgsql_query('{sql}','{host}','{port}','{user}','password','{dbname}',''{secrets_manager_key}) called")
+
+    if secrets_manager_key:
+        secret = json.loads(awsUtils.secrets_manager_get_secret(secrets_manager_key))
+        host = secret["host"]
+        logger.debug(f"host: {host}")
+        port = secret["port"]
+        logger.debug(f"port: {port}")
+        dbname = secret["dbname"]
+        logger.debug(f"dbname: {dbname}")
+        user = secret["username"]
+        logger.debug(f"user: {user}")
+        password = secret["password"]
+
+    conn =  psycopg2.connect(dbname=dbname, user=user, password=password, host=host, port=port)
+    cur = conn.cursor()
+    try:
+        cur.execute(sql)
+    except psycopg2.Error as e:
+        return str(e)
+    else:
+        conn.commit()
+        # fetch the column names
+        columns = [desc[0] for desc in cur.description]
+        results = [dict(zip(columns, row)) for row in cur.fetchall()]
+
+        return results
+    finally:
+        cur.close()
+        conn.close()
